summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql3/src/vdbeaux.c
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kexisql3/src/vdbeaux.c')
-rw-r--r--kexi/3rdparty/kexisql3/src/vdbeaux.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/kexi/3rdparty/kexisql3/src/vdbeaux.c b/kexi/3rdparty/kexisql3/src/vdbeaux.c
index cba9c096d..6b37312de 100644
--- a/kexi/3rdparty/kexisql3/src/vdbeaux.c
+++ b/kexi/3rdparty/kexisql3/src/vdbeaux.c
@@ -176,7 +176,7 @@ void sqlite3VdbeResolveLabel(Vdbe *p, int x){
*/
static int opcodeNoPush(u8 op){
/* The 10 NOPUSH_MASK_n constants are defined in the automatically
- ** generated header file opcodes.h. Each is a 16-bit bitmask, one
+ ** generated header file opcodes.h. Each is a 16-bit bittqmask, one
** bit corresponding to each opcode implemented by the virtual
** machine in vdbe.c. The bit is true if the word "no-push" appears
** in a comment on the same line as the "case OP_XXX:" in
@@ -186,23 +186,23 @@ static int opcodeNoPush(u8 op){
** to grow the stack when it is executed. Otherwise, it may grow the
** stack by at most one entry.
**
- ** NOPUSH_MASK_0 corresponds to opcodes 0 to 15. NOPUSH_MASK_1 contains
+ ** NOPUSH_MASK_0 corresponds to opcodes 0 to 15. NOPUSH_MASK_1 tqcontains
** one bit for opcodes 16 to 31, and so on.
**
- ** 16-bit bitmasks (rather than 32-bit) are specified in opcodes.h
+ ** 16-bit bittqmasks (rather than 32-bit) are specified in opcodes.h
** because the file is generated by an awk program. Awk manipulates
** all numbers as floating-point and we don't want to risk a rounding
** error if someone builds with an awk that uses (for example) 32-bit
** IEEE floats.
*/
- static const u32 masks[5] = {
+ static const u32 tqmasks[5] = {
NOPUSH_MASK_0 + (NOPUSH_MASK_1<<16),
NOPUSH_MASK_2 + (NOPUSH_MASK_3<<16),
NOPUSH_MASK_4 + (NOPUSH_MASK_5<<16),
NOPUSH_MASK_6 + (NOPUSH_MASK_7<<16),
NOPUSH_MASK_8 + (NOPUSH_MASK_9<<16)
};
- return (masks[op>>5] & (1<<(op&0x1F)));
+ return (tqmasks[op>>5] & (1<<(op&0x1F)));
}
#ifndef NDEBUG
@@ -1326,15 +1326,15 @@ int sqlite3VdbeFinalize(Vdbe *p){
/*
** Call the destructor for each auxdata entry in pVdbeFunc for which
** the corresponding bit in mask is clear. Auxdata entries beyond 31
** are always destroyed. To destroy all auxdata entries, call this
-** routine with mask==0.
+** routine with tqmask==0.
*/
-void sqlite3VdbeDeleteAuxData(VdbeFunc *pVdbeFunc, int mask){
+void sqlite3VdbeDeleteAuxData(VdbeFunc *pVdbeFunc, int tqmask){
int i;
for(i=0; i<pVdbeFunc->nAux; i++){
struct AuxData *pAux = &pVdbeFunc->apAux[i];
- if( (i>31 || !(mask&(1<<i))) && pAux->pAux ){
+ if( (i>31 || !(tqmask&(1<<i))) && pAux->pAux ){
if( pAux->xDelete ){
pAux->xDelete(pAux->pAux);
}
@@ -1326,15 +1326,15 @@ int sqlite3VdbeFinalize(Vdbe *p){
/*
** Call the destructor for each auxdata entry in pVdbeFunc for which
-** the corresponding bit in mask is clear. Auxdata entries beyond 31
+** the corresponding bit in tqmask is clear. Auxdata entries beyond 31
** are always destroyed. To destroy all auxdata entries, call this